@@ -21,17 +21,21 @@
 
 #include "libbcachefs.h"
 #include "crypto.h"
-#include "libbcachefs/bcachefs_format.h"
-#include "libbcachefs/btree_cache.h"
-#include "libbcachefs/buckets.h"
-#include "libbcachefs/checksum.h"
-#include "libbcachefs/disk_groups.h"
-#include "libbcachefs/journal_seq_blacklist.h"
-#include "libbcachefs/opts.h"
-#include "libbcachefs/replicas.h"
-#include "libbcachefs/super-io.h"
 #include "tools-util.h"
 
+#include "bcachefs.h"
+
+#include "alloc/buckets.h"
+#include "alloc/disk_groups.h"
+#include "alloc/replicas.h"
+#include "btree/cache.h"
+
+#include "data/checksum.h"
+
+#include "journal/seq_blacklist.h"
+
+#include "sb/io.h"
+
 #define NSEC_PER_SEC	1000000000L
 
 void bch2_sb_layout_init(struct bch_sb_layout *l,
@@ -559,7 +563,7 @@ read_super:
 		struct bch_sb_handle sb;
 		int ret = bch2_read_super(path, &opts, &sb);
 		if (ret)
-			die("Error opening %s: %s", path, strerror(-ret));
+			return ret;
 
 		fs->dev_idx = sb.sb->dev_idx;
 		uuid_str = buf;
@@ -865,7 +869,7 @@ struct bch_opts bch2_parse_opts(struct bch_opt_strs strs)
 void bch2_opts_usage(unsigned opt_types)
 {
 	const struct bch_option *opt;
-	unsigned i, c = 0, helpcol = 30;
+	unsigned i, c = 0, helpcol = 32;
 
 	for (opt = bch2_opt_table;
 	     opt < bch2_opt_table + bch2_opts_nr;
@@ -895,13 +899,14 @@ void bch2_opts_usage(unsigned opt_types)
 		if (opt->help) {
 			const char *l = opt->help;
 
-			if (c >= helpcol)
+			if (c > helpcol) {
 				newline(c);
+			}
 
 			while (1) {
 				const char *n = strchrnul(l, '\n');
 
-				while (c < helpcol) {
+				while (c < helpcol-1) {
 					putchar(' ');
 					c++;
 				}
